@@ -30,15 +30,15 @@ describe OmniAuth::Strategies::GoogleOauth2 do
 
   describe '#client_options' do
     it 'has correct site' do
-      expect(subject.client.site).to eq('https://accounts.google.com')
+      expect(subject.client.site).to eq('https://oauth2.googleapis.com')
     end
 
     it 'has correct authorize_url' do
-      expect(subject.client.options[:authorize_url]).to eq('/o/oauth2/auth')
+      expect(subject.client.options[:authorize_url]).to eq('https://accounts.google.com/o/oauth2/auth')
     end
 
     it 'has correct token_url' do
-      expect(subject.client.options[:token_url]).to eq('/o/oauth2/token')
+      expect(subject.client.options[:token_url]).to eq('/token')
     end
 
     describe 'overrides' do
@@ -304,9 +304,7 @@ describe OmniAuth::Strategies::GoogleOauth2 do
       OAuth2::Client.new('abc', 'def') do |builder|
         builder.request :url_encoded
         builder.adapter :test do |stub|
-          stub.get('/plus/v1/people/me/openIdConnect') { [200, { 'content-type' => 'application/json' }, '{"sub": "12345"}'] }
-          stub.get('/plus/v1/people/12345/people/visible') { [200, { 'content-type' => 'application/json' }, '[{"foo":"bar"}]'] }
-          stub.get('/plus/v1/people/12345?fields=image') { [200, { 'content-type' => 'application/json' }, '{"image":"imageData"}'] }
+          stub.get('/oauth2/v3/userinfo') { [200, { 'content-type' => 'application/json' }, '{"sub": "12345"}'] }
         end
       end
     end
@@ -315,35 +313,60 @@ describe OmniAuth::Strategies::GoogleOauth2 do
     before { allow(subject).to receive(:access_token).and_return(access_token) }
 
     describe 'id_token' do
-      context 'when the id_token is passed into the access token' do
-        token_info =
+      shared_examples 'id_token issued by valid issuer' do |issuer| # rubocop:disable Metrics/BlockLength
+        context 'when the id_token is passed into the access token' do
+          let(:token_info) do
+            {
+              'abc' => 'xyz',
+              'exp' => Time.now.to_i + 3600,
+              'nbf' => Time.now.to_i - 60,
+              'iat' => Time.now.to_i,
+              'aud' => 'appid',
+              'iss' => issuer
+            }
+          end
+          let(:id_token) { JWT.encode(token_info, 'secret') }
+          let(:access_token) { OAuth2::AccessToken.from_hash(client, 'id_token' => id_token) }
+
+          it 'should include id_token when set on the access_token' do
+            expect(subject.extra).to include(id_token: id_token)
+          end
+
+          it 'should include id_info when id_token is set on the access_token and skip_jwt is false' do
+            subject.options[:skip_jwt] = false
+            expect(subject.extra).to include(id_info: token_info)
+          end
+
+          it 'should not include id_info when id_token is set on the access_token and skip_jwt is true' do
+            subject.options[:skip_jwt] = true
+            expect(subject.extra).not_to have_key(:id_info)
+          end
+
+          it 'should include id_info when id_token is set on the access_token by default' do
+            expect(subject.extra).to include(id_info: token_info)
+          end
+        end
+      end
+
+      it_behaves_like 'id_token issued by valid issuer', 'accounts.google.com'
+      it_behaves_like 'id_token issued by valid issuer', 'https://accounts.google.com'
+
+      context 'when the id_token is issued by an invalid issuer' do
+        let(:token_info) do
           {
             'abc' => 'xyz',
             'exp' => Time.now.to_i + 3600,
             'nbf' => Time.now.to_i - 60,
             'iat' => Time.now.to_i,
             'aud' => 'appid',
-            'iss' => 'accounts.google.com'
+            'iss' => 'fake.google.com'
           }
-        id_token = JWT.encode(token_info, 'secret')
+        end
+        let(:id_token) { JWT.encode(token_info, 'secret') }
         let(:access_token) { OAuth2::AccessToken.from_hash(client, 'id_token' => id_token) }
 
-        it 'should include id_token when set on the access_token' do
-          expect(subject.extra).to include(id_token: id_token)
-        end
-
-        it 'should include id_info when id_token is set on the access_token and skip_jwt is false' do
-          subject.options[:skip_jwt] = false
-          expect(subject.extra).to include(id_info: token_info)
-        end
-
-        it 'should not include id_info when id_token is set on the access_token and skip_jwt is true' do
-          subject.options[:skip_jwt] = true
-          expect(subject.extra).not_to have_key(:id_info)
-        end
-
-        it 'should include id_info when id_token is set on the access_token by default' do
-          expect(subject.extra).to include(id_info: token_info)
+        it 'raises JWT::InvalidIssuerError' do
+          expect { subject.extra }.to raise_error(JWT::InvalidIssuerError)
         end
       end
 
@@ -375,66 +398,6 @@ describe OmniAuth::Strategies::GoogleOauth2 do
         end
       end
     end
-
-    describe 'raw_friend_info' do
-      context 'when skip_info is true' do
-        before { subject.options[:skip_info] = true }
-
-        it 'should not include raw_friend_info' do
-          expect(subject.extra).not_to have_key(:raw_friend_info)
-        end
-      end
-
-      context 'when skip_info is false' do
-        before { subject.options[:skip_info] = false }
-
-        context 'when skip_friends is true' do
-          before { subject.options[:skip_friends] = true }
-
-          it 'should not include raw_friend_info' do
-            expect(subject.extra).not_to have_key(:raw_friend_info)
-          end
-        end
-
-        context 'when skip_friends is false' do
-          before { subject.options[:skip_friends] = false }
-
-          it 'should not include raw_friend_info' do
-            expect(subject.extra[:raw_friend_info]).to eq([{ 'foo' => 'bar' }])
-          end
-        end
-      end
-    end
-
-    describe 'raw_image_info' do
-      context 'when skip_info is true' do
-        before { subject.options[:skip_info] = true }
-
-        it 'should not include raw_image_info' do
-          expect(subject.extra).not_to have_key(:raw_image_info)
-        end
-      end
-
-      context 'when skip_info is false' do
-        before { subject.options[:skip_info] = false }
-
-        context 'when skip_image_info is true' do
-          before { subject.options[:skip_image_info] = true }
-
-          it 'should not include raw_image_info' do
-            expect(subject.extra).not_to have_key(:raw_image_info)
-          end
-        end
-
-        context 'when skip_image_info is false' do
-          before { subject.options[:skip_image_info] = false }
-
-          it 'should include raw_image_info' do
-            expect(subject.extra[:raw_image_info]).to eq('image' => 'imageData')
-          end
-        end
-      end
-    end
   end
 
   describe 'populate auth hash urls' do
@@ -599,37 +562,6 @@ describe OmniAuth::Strategies::GoogleOauth2 do
     end
   end
 
-  describe 'verify_iss option' do
-    before(:each) do
-      subject.options.client_options[:connection_build] = proc do |builder|
-        builder.request :url_encoded
-        builder.adapter :test do |stub|
-          stub.get('/oauth2/v3/tokeninfo?access_token=invalid_iss_token') do
-            [200, { 'Content-Type' => 'application/json; charset=UTF-8' },
-             JSON.dump(
-               aud: '000000000000.apps.googleusercontent.com',
-               sub: '123456789',
-               email_verified: 'true',
-               email: 'example@example.com',
-               access_type: 'offline',
-               scope: 'profile email',
-               expires_in: 436,
-               iss: 'foobar.com'
-             )]
-          end
-        end
-      end
-      subject.options.authorized_client_ids = ['000000000000.apps.googleusercontent.com']
-      subject.options.client_id = '000000000000.apps.googleusercontent.com'
-      subject.options[:verify_iss] = false
-    end
-
-    it 'should verify token if the iss does not match options.expected_iss' do
-      result = subject.send(:verify_token, 'invalid_iss_token')
-      expect(result).to eq(true)
-    end
-  end
-
   describe 'verify_token' do
     before(:each) do
       subject.options.client_options[:connection_build] = proc do |builder|
@@ -679,7 +611,7 @@ describe OmniAuth::Strategies::GoogleOauth2 do
       OAuth2::Client.new('abc', 'def') do |builder|
         builder.request :url_encoded
         builder.adapter :test do |stub|
-          stub.get('/plus/v1/people/me/openIdConnect') do
+          stub.get('/oauth2/v3/userinfo') do
             [200, { 'Content-Type' => 'application/json; charset=UTF-8' }, JSON.dump(
               hd: 'example.com'
             )]
@@ -694,7 +626,7 @@ describe OmniAuth::Strategies::GoogleOauth2 do
         OAuth2::Client.new('abc', 'def') do |builder|
           builder.request :url_encoded
           builder.adapter :test do |stub|
-            stub.get('/plus/v1/people/me/openIdConnect') do
+            stub.get('/oauth2/v3/userinfo') do
               [200, { 'Content-Type' => 'application/json; charset=UTF-8' }, JSON.dump({})]
             end
           end
